package info.textgrid.lab.collatex.ui.parts;

import info.textgrid.lab.core.model.TGContentType;
import info.textgrid.lab.core.model.TextGridObject;
import info.textgrid.lab.ui.core.dialogs.NewObjectWizard;
import info.textgrid.lab.ui.core.menus.OpenObjectService;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.part.IPageSite;
import org.eclipse.ui.part.Page;
import org.eclipse.wb.swt.ResourceManager;

/**
 * The {@linkplain AbstractResultView result views} show this page when no
 * collation relevant editor is active. It contains an introduction on how to
 * use the CollateX UI.
 */
public class DefaultResultPage extends Page {

	private Composite control;

	/**
	 * Create the PageBookView Page.
	 */
	public DefaultResultPage() {
	}

	/**
	 * Create contents of the PageBookView Page.
	 * @param parent
	 */
	@Override
	public void createControl(final Composite parent) {
		final Composite container = new Composite(parent, SWT.NULL);

		control = container;
		container.setLayout(new GridLayout(1, false));
		// {
		// final Label explanationLabel = new Label(container, SWT.WRAP);
		// explanationLabel.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER,
		// true, false, 1, 1));
		// explanationLabel
		// .setText(Messages.DefaultResultPage_ViewExplanation);
		// }
		{
			final CLabel titleLabel = new CLabel(container, SWT.NONE);
			titleLabel.setText(Messages.DefaultResultPage_lblToGetStarted_text);
			titleLabel.setFont(JFaceResources.getBannerFont());
		}
		{
			final Composite composite = new Composite(container, SWT.NONE);
			composite.setLayout(new RowLayout(SWT.HORIZONTAL));
			composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, false,
					false, 1, 1));
			{
				final Button lblCreateANew = new Button(composite, SWT.NONE);
				lblCreateANew.addSelectionListener(new SelectionAdapter() {
					@Override
					public void widgetSelected(final SelectionEvent e) {
						final NewObjectWizard wizard = new NewObjectWizard();
						wizard.showDialog(getSite().getShell(),
								null,
								TGContentType.of("text/collation-set+xml")); //$NON-NLS-1$
					}
				});
				lblCreateANew.setImage(ResourceManager.getPluginImage(
						"info.textgrid.lab.collatex", //$NON-NLS-1$
						"resources/icons/155-Datei-Icon-Collation-Set.gif")); //$NON-NLS-1$
				lblCreateANew
				.setText(Messages.DefaultResultPage_lblCreateANew_text);
			}
			{
				final Button btnOrOpenAn = new Button(composite, SWT.NONE);
				btnOrOpenAn.addSelectionListener(new SelectionAdapter() {
					@Override
					public void widgetSelected(final SelectionEvent e) {
						final TextGridObject object = SelectObjectDialog
								.selectObject(getSite().getShell(),
										"format:\"text/collation-set+xml\"", //$NON-NLS-1$
										Messages.DefaultResultPage_OpenCSDialogTitle,
										Messages.DefaultResultPage_OpenCSTitle,
										Messages.DefaultResultPage_OpenCSMessage, null);
						if (object != null)
							OpenObjectService.getInstance().openObject(object,
									0, false);
					}
				});
				btnOrOpenAn
				.setText(Messages.DefaultResultPage_btnOrOpenAn_text);
			}
		}
		{
			final CLabel lblDragText = new CLabel(container, SWT.NONE);
			lblDragText.setImage(ResourceManager.getPluginImage(
					"org.eclipse.wst.xml.ui", "/icons/full/obj16/text.gif")); //$NON-NLS-1$ //$NON-NLS-2$
			lblDragText.setText(Messages.DefaultResultPage_lblDragText_text);
		}
		{
			final CLabel lblSaveYour = new CLabel(container, SWT.NONE);
			lblSaveYour.setImage(ResourceManager.getPluginImage(
					"org.eclipse.ui", "/icons/full/etool16/save_edit.gif")); //$NON-NLS-1$ //$NON-NLS-2$
			lblSaveYour.setText(Messages.DefaultResultPage_lblSaveYour_text);
		}
		{
			final CLabel lblClickThe = new CLabel(container, SWT.NONE);
			lblClickThe.setImage(ResourceManager.getPluginImage(
					"info.textgrid.lab.collatex", //$NON-NLS-1$
					"resources/icons/157-starte-Kollationierung.gif")); //$NON-NLS-1$
			lblClickThe.setText(Messages.DefaultResultPage_lblClickThe_text);
		}
		System.out.println("Default Result Page set."); //$NON-NLS-1$

	}

	@Override
	public Control getControl() {
		return control;
	}

	@Override
	public void init(final IPageSite pageSite) {
		super.init(pageSite);
		createActions();
		initializeToolBar();
		initializeMenu();
	}

	@Override
	public void setFocus() {
		// Set the focus
	}

	/**
	 * Create the actions.
	 */
	private void createActions() {
		// Create the actions
	}

	/**
	 * Initialize the toolbar.
	 */
	private void initializeToolBar() {
		final IToolBarManager toolbarManager = getSite().getActionBars()
				.getToolBarManager();
	}

	/**
	 * Initialize the menu.
	 */
	private void initializeMenu() {
		final IMenuManager menuManager = getSite().getActionBars().getMenuManager();
	}
}
